package com.ruoyi.system.service;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.common.core.domain.entity.Mark;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2021-11-19
 */
public interface IMarkService  extends IService<Mark>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public Mark selectMarkById(Long id);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param mark 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<Mark> selectMarkList(Mark mark);

    /**
     * 新增【请填写功能名称】
     *
     * @param mark 【请填写功能名称】
     * @return 结果
     */
    public int insertMark(Mark mark);

    /**
     * 修改【请填写功能名称】
     *
     * @param mark 【请填写功能名称】
     * @return 结果
     */
    public int updateMark(Mark mark);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteMarkByIds(Long[] ids);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteMarkById(Long id);
}
